summaryrefslogtreecommitdiff
path: root/libnautilus-extensions/nautilus-bookmark.h
diff options
context:
space:
mode:
authorJohn Sullivan <sullivan@src.gnome.org>2001-03-21 01:07:08 +0000
committerJohn Sullivan <sullivan@src.gnome.org>2001-03-21 01:07:08 +0000
commit65e9e66c73a1a883eb2ae309a9f20ca05079e3db (patch)
treea8765fcbb8f22ae3b7b2b242ab2d63e4aaacfa0e /libnautilus-extensions/nautilus-bookmark.h
parent13a6070f0db76d1a8edd453e321ed8f0c45b9268 (diff)
downloadnautilus-65e9e66c73a1a883eb2ae309a9f20ca05079e3db.tar.gz
Fixed bug 4355: Built-in bookmarks icons change after first view
Also reduced the number of times that refresh_bookmarks_menu is called since it was showing up in some profiling. * libnautilus-extensions/nautilus-bookmark.h: * libnautilus-extensions/nautilus-bookmark.c: (nautilus_bookmark_initialize_class), (nautilus_bookmark_set_name), (bookmark_file_changed_callback): Split the "changed" signal into "appearance_changed" and "content_changed". "appearance_changed" is emitted only if the name or icon change. "content_changed" is emitted if the URI changes. * src/nautilus-bookmark-list.c: (insert_bookmark_internal): Connect to both appearance_changed and content_changed. * src/nautilus-window-menus.c: (bookmark_holder_new): Refresh menu only on appearance_changed, not content_changed. * data/static_bookmarks.xml: Added "i-web" as icon name for all the built-in bookmarks, since this is the icon they will end up with after being visited. (Now, visiting a built-in bookmark will not cause a refresh of the bookmarks menu.)
Diffstat (limited to 'libnautilus-extensions/nautilus-bookmark.h')
-rw-r--r--libnautilus-extensions/nautilus-bookmark.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/libnautilus-extensions/nautilus-bookmark.h b/libnautilus-extensions/nautilus-bookmark.h
index 97e4363f9..08240e1f2 100644
--- a/libnautilus-extensions/nautilus-bookmark.h
+++ b/libnautilus-extensions/nautilus-bookmark.h
@@ -56,10 +56,15 @@ struct NautilusBookmarkClass {
/* Signals that clients can connect to. */
/* The changed signal is emitted when the bookmark's
* name or icon has changed.
*/
- void (* changed) (NautilusBookmark *bookmark);
+ void (* appearance_changed) (NautilusBookmark *bookmark);
+
+ /* The contents_changed signal is emitted when the bookmark's
+ * URI has changed.
+ */
+ void (* contents_changed) (NautilusBookmark *bookmark);
};
typedef struct NautilusBookmarkClass NautilusBookmarkClass;
@@ -56,10 +56,15 @@ struct NautilusBookmarkClass {
/* Signals that clients can connect to. */
- /* The changed signal is emitted when the bookmark's
+ /* The appearance_changed signal is emitted when the bookmark's
* name or icon has changed.
*/